@@ -5,6 +5,7 @@ __all__ = [
     "arg",
     "io",
     "ddp",
+    "dummy",
     "metrics",
     "serve",
     "tensor",
@@ -12,8 +13,8 @@ __all__ = [
     "travel",
     "utils",
 ]
-_optional = ["bert", "mlflow", "tune"]
-__version__ = "0.3.0"
+_optional = ["hugging", "mlflow", "tune"]
+__version__ = "0.3.2"
 
 for submodule in __all__:
     import_module(f"pytorch_quik.{submodule}")
